.. _toxic:

toxic
#####

Haldol:

| 128 mg/kg [Rat]
| 71 mg/kg [Mouse]
| 90 mg/kg [Dog].

Zyprexa:

| Oral LDLO (man): 7067 ug/kg
| Oral TDLO (woman): 400 ug/kg
| Subcutaneous TDLO (rat): 625 ug/kg
| Intraperitoneal TDLO rat 5 mg/kg;

Clozapine:

| Oral TDLO (man): 27 mg/kg/13D (intermittent)
| Oral TDLO (woman): 20 mg/kg
| Oral TDLO (child): 4762 μg/kg
| Oral LD50 (rat): 251 mg/kg
| Subcutaneous LD50 (rat): 240 mg/kg
| Oral LD50 (mouse): 150 mg/kg
| Subcutaneous LD50 (mouse): 194 mg/kg
| Subcutaneous TDLO (rat): 240 mg/kg;

Abilify:

| 10 mg/kg

Orap:

| LDL [Human] - Route: Oral Dose: 192mg/kg
| LDL [Woman] - Route: Oral; Dose; 400 mg/kg
| LDL [Child] - Route: Oral; Dose: 320 mg/kg

Cannibidiol:

| Intravenous LD50 (mouse): 50 mg/kg
| Oral TDLo (human): 5.63 mg/kg;

THC:

| 666 MG/KG ORAL-RAT LD50
| 482 MG/KG ORAL-MOUSE LD50
| 525 MG/KG ORAL-DOG LDLO
| 29 MG/KG INTRAVENOUS-RAT LD50
| 42 MG/KG INTRAVENOUS-MOUSE LD50
| 128 MG/KG INTRAVENOUS-MONKEY LDLO
| 373 MG/KG INTRAPERITONEAL-RAT LD50
| 168 MG/KG INTRAPERITONEAL-MOUSE LD50

Caffeine:

| LDL [Human] 192mg/kg
| LDL [Woman] 400 mg/kg
| LDL [Child] 320 mg/kg
| Acute oral toxicity (LD50): 127 mg/kg [Mouse].

Nicotine:

| Acute oral toxicity (LD50): 3.34 mg/kg [Mouse]
| Acute dermal toxicity (LD50): 50 mg/kg [Rabbit].

Alcohol:

| LD 50 (Rat): 5,045 mg/kg
| LD 50 (Rabbit): 12,800 mg/kg

Cocaine:

| LD50 96 mg/kg [Mouse].

GHB (sodium salt):

| LD50 (rat): 9690 mg/kg
| Intraperitoneal LD50 (rat): 1650mg/kg
| Intraperitoneal LD50 (mouse): 1940 mg/kg
| Oral LD50 (mouse): 4250 mg/kg;

Alprazolam:

| Rat Oral LD 50 1220 (F) mg/kg
| Rat Oral LD 50 3100 (M) mg/kg,
| Mouse Oral LD 50 1410-1700mg/kg
| Rat Intravenous LD 50 ~ 15 mg/kg

Oxazepam:

| Rat Oral LD50 >8 g/kg
| Mouse Oral LD50 1540 mg/kg
| Rabbit Oral LD50 >2 g/kg
| Rat Subcutaneous LD50 >8 g/kg
| Mouse Subcutaneous LD50 >400 mg/kg

Fuoxetine Hydrochloride:

| Oral (rat) LD50: 452 mg/kg
| Oral (mouse) LD50: 248 mg/kg
| Intraperitoneal (mouse) LD50: 100 mg/kg
| Oral (man) TDLo: 3.73 mg/kg/24h - I *

Citalopram:

| Intraperitoneal LD (rat): >10 mg/kg
| Intraperitoneal TDLO (mouse): 16 mg/kg
| Intraperitoneal TDLO (rat): 10 mg/kg
| Oral TDLO (rat): 10 mg/kg;
| Oral TDLO (man): 35.3 mg/kg
| Oral TDLO (mouse): 7.5 mg/kg;

Paroxetine:

| Oral TDLO (man): 3654 μg/kg/14D (intermittent)
| Oral TDLO (man): 625 μg/kg
| Oral LD50 (rat): 415 mg/kg
| Oral LD50 (mouse): 378 mg/kg
| Intraperitoneal TDLO (mouse): 4 mg/kg
| Subcutaneous TDLO (mouse): 0.03 mg/kg
| Oral TDLO (rat): 10 mg/kg



